==> sql_tools-1.1.0-py3-none-any.whl: sql_tools/sqlite/__tools.py <==
"""
*Not for user. Don't modify, delete, use it.*
Contains tools for sql-tools library to work-properly
"""

import logging
import os
import time
from . import fetch

import pandas as pd
import numpy as np

from . import constants, sqliteException


def setStatus(arg, logConsole=False, raiseError=True):
    try:
        if logConsole:
            logging.basicConfig(format="[%(process)d] SQL-Tools: %(message)s")
            logging.warning(arg)  # Change the logging style
            constants.__processId__ = os.getpid()
        else:
            constants.__history__.append(arg)
        constants.__status__ = arg
        return True
    except Exception:
        if raiseError:
            raise sqliteException.UnknownError("Unable to set the status.")
        else:
            return False


def __tableToCSV(data, tableName, databPath="", table=True, database=True, index=False):
    constants.__startTime__ = time.time()
    databPath = fetch._pdatabase(databPath)

    databPath = databPath[
        0
    ]  # REMOVE THIS FOR MULTIPLE DATABASES AS IT WILL FETCH THE FIRST DATABASE ONLY

    columns = fetch.getColumnNames(tableName, databPath=databPath)[0]
    if table and database:
        if index != False:
            pd.DataFrame(data, columns=columns, index=index).to_csv(
                f"{os.path.basename(databPath)}.{tableName}.csv"
            )
        else:
            pd.DataFrame(data, columns=columns).to_csv(
                f"{os.path.basename(databPath)}.{tableName}.csv", index=False
            )
    elif table:
        if index != False:
            pd.DataFrame(data, columns=columns, index=index).to_csv(f"{tableName}.csv")
        else:
            pd.DataFrame(data, columns=columns).to_csv(f"{tableName}.csv", index=False)

    # else:
    #     raise AttributeError("One attribute must be provided.")
    constants.__stopTime__ = time.time()
    constants.__time__ = (
        f"Wall time: {(constants.__stopTime__ - constants.__startTime__)*10}s"
    )
    return True


def dataType(data):
    try:
        dtype = np.array(data).dtype
        print(dtype)
        if (
            dtype == "O"
            or dtype == "<U1"
            or dtype == "<U5"
            or dtype == "<U6"
            or dtype == "<U7"
            or dtype == "<U11"
            or dtype == "<U21"
        ):
            return "str"
        elif (
            dtype == "int64"
            or dtype == "<U2"
        ):
            return "int"
        else:
            return "None"

    except Exception:
        pass


if __name__ == "__main__":
    print("Tools extension for SQL-Tools library.")
    print("Note: Don't use it seperately otherwise MAY CAUSE THE PROGRAM TO STOP.")

==> sql_tools-2.0.0-py3-none-any.whl: sql_tools/sqlite/__tools.py <==
"""
*Not for user. Don't modify, delete, use it.*
Contains tools for sql-tools library to work-properly
"""

import logging
import os
import time
from . import fetch

import pandas as pd
import numpy as np

from . import constants, sqliteException


def setStatus(arg, logConsole=False, raiseError=True):
    try:
        if logConsole:
            logging.basicConfig(format="[%(process)d] SQL-Tools: %(message)s")
            logging.warning(arg)  # Change the logging style
            constants.__pid__ = os.getpid()
        else:
            constants.__history__.append(arg)
        constants.__status__ = arg
        return True
    except Exception:
        if raiseError:
            raise sqliteException.UnknownError("Unable to set the status.")
        else:
            return False


def __tableToCSV(data, tableName, databPath="", table=True, database=True, index=False):
    constants.__startTime__ = time.time()
    databPath = fetch._pdatabase(databPath)

    databPath = databPath[
        0
    ]  # REMOVE THIS FOR MULTIPLE DATABASES AS IT WILL FETCH THE FIRST DATABASE ONLY

    columns = fetch.getCNames(tableName, databPath=databPath)[0]
    if table and database:
        if index != False:
            pd.DataFrame(data, columns=columns, index=index).to_csv(
                f"{os.path.basename(databPath)}.{tableName}.csv"
            )
        else:
            pd.DataFrame(data, columns=columns).to_csv(
                f"{os.path.basename(databPath)}.{tableName}.csv", index=False
            )
    elif table:
        if index != False:
            pd.DataFrame(data, columns=columns, index=index).to_csv(f"{tableName}.csv")
        else:
            pd.DataFrame(data, columns=columns).to_csv(f"{tableName}.csv", index=False)

    # else:
    #     raise AttributeError("One attribute must be provided.")
    constants.__stopTime__ = time.time()
    constants.__time__ = (
        f"Wall time: {(constants.__stopTime__ - constants.__startTime__)*10}s"
    )
    return True


def dataType(data):
    try:
        dtype = np.array(data).dtype
        print(dtype)
        if (
            dtype == "O"
            or dtype == "<U1"
            or dtype == "<U5"
            or dtype == "<U6"
            or dtype == "<U7"
            or dtype == "<U11"
            or dtype == "<U21"
        ):
            return "str"
        elif (
            dtype == "int64"
            or dtype == "<U2"
        ):
            return "int"
        else:
            return "None"

    except Exception:
        pass


if __name__ == "__main__":
    print("Tools extension for SQL-Tools library.")
    print("Note: Don't use it seperately otherwise MAY CAUSE THE PROGRAM TO STOP.")
